@@ -317,7 +317,10 @@ def transform_lists_to_arrays(module, to_change, __funcs, vec=False, cache_black
         if type(orig_func) is type:
             obj = new_func
         else:
-            obj = conv_fun(cache=do_cache, parallel=parallel, **extra_args)(new_func)
+            if vec:
+                obj = conv_fun(cache=do_cache, **extra_args)(new_func)
+            else:
+                obj = conv_fun(cache=do_cache, parallel=parallel, **extra_args)(new_func)
 #        if 'Wilke_large' in source:
 #            print(id(obj), 'id')
         __funcs[func] = obj
@@ -468,6 +471,10 @@ def create_numerics(replaced, vec=False):
 
     NUMERICS_SUBMOD.normalize = normalize
     replaced['normalize'] = normalize
+    for k, v in NUMERICS_SUBMOD.fit_minimization_targets.items():
+        NUMERICS_SUBMOD.fit_minimization_targets[k] = replaced[v.__name__]
+    
+    
     return replaced, NUMERICS_SUBMOD
 
 replaced = {'sum': np.sum, 'combinations': combinations, 'np': np}
